@@ -208,20 +208,15 @@ class MsSqlProvider(DatabaseProvider):
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.UNIQUE_LOGIN:
             return f"( SELECT NEWID() )"
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.FAKE_UPDATE:
-            return f"( SELECT TOP 1 [{column_strategy.qualifier}] FROM [{SEED_TABLE_NAME}] ORDER BY NEWID())"
+            column = f"[{column_strategy.qualifier}]"
+            if column_strategy.sql_type:
+                column = f"CAST({column} AS {column_strategy.sql_type})"
+            return f"( SELECT TOP 1 {column} FROM [{SEED_TABLE_NAME}] ORDER BY NEWID())"
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.LITERAL:
             return column_strategy.value
         else:
             raise UnsupportedColumnStrategyError(column_strategy)
 
-    def test_connection(self):
-        import pyodbc
-        try:
-            self.__execute("SELECT @@VERSION;").fetchall()
-            return True
-        except pyodbc.Error:
-            return False
-
     def create_database(self):
         self.logger.warning("MSSQL: create_database ignored, database will be created when restore_db is run")
 
@@ -236,7 +231,7 @@ class MsSqlProvider(DatabaseProvider):
         if len(qualifier_map) > 0:
             self.logger.info("creating seed table with %d columns", len(qualifier_map))
             self.__create_seed_table(qualifier_map)
-            
+
             self.logger.info("Inserting seed data")
             self.__seed(qualifier_map)
 
@@ -254,6 +249,10 @@ class MsSqlProvider(DatabaseProvider):
                     progressbar.set_description("Truncating {}".format(table_name))
                     self.__db_execute("TRUNCATE TABLE {}[{}];".format(schema_prefix, table_name))
 
+                elif table_strategy.strategy_type == TableStrategyTypes.DELETE:
+                    progressbar.set_description("Deleting {}".format(table_name))
+                    self.__db_execute("DELETE FROM {}[{}];".format(schema_prefix, table_name))
+
                 elif table_strategy.strategy_type == TableStrategyTypes.UPDATE_COLUMNS:
                     progressbar.set_description("Anonymizing {}".format(table_name))
                     where_grouping = table_strategy.group_by_where()
