@@ -31,7 +31,10 @@ def _get_column_subquery(seed_table_name, column_strategy):
         # Add a dummy "updatetarget" where clause to fool the postgres optimizer into running the subquery on every row
         # instead of once for the whole query
         # See Also https://www.simononsoftware.com/problem-with-random-in-postgresql-subselect/
-        return f"( SELECT {column_strategy.qualifier} FROM {seed_table_name} WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1)"
+        column = column_strategy.qualifier
+        if column_strategy.sql_type:
+            column += "::" + column_strategy.sql_type
+        return f"( SELECT {column} FROM {seed_table_name} WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1)"
     elif column_strategy.strategy_type == UpdateColumnStrategyTypes.LITERAL:
         return column_strategy.value
     else:
@@ -56,6 +59,11 @@ def _get_qualified_table_name(schema, table):
 def get_truncate_table(table_strategy):
     return f"TRUNCATE TABLE {_get_qualified_table_name(table_strategy.schema, table_strategy.table_name)} CASCADE;"
 
+# postgres truncates can cascade and are faster than unqualified deletes
+# https://www.postgresql.org/docs/9.1/sql-truncate.html
+def get_delete_table(table_strategy):
+    return f"TRUNCATE TABLE {_get_qualified_table_name(table_strategy.schema, table_strategy.table_name)} CASCADE;"
+
 
 def get_create_seed_table(table_name, qualifier_map):
     if len(qualifier_map) < 1:
@@ -98,7 +106,7 @@ def get_update_table(seed_table_name, update_table_strategy):
     for where, column_map in update_table_strategy.group_by_where().items():
         where_update_statements[where] = []
         for column_name, column_strategy in column_map.items():
-            where_update_statements[where].append("{} = {}".format(
+            where_update_statements[where].append("\"{}\" = {}".format(
                 column_name,
                 _get_column_subquery(seed_table_name, column_strategy))
             )
